@@ -352,7 +352,9 @@ static int grabFields(gsl_matrix *m, const char *rowStart, int row, GArray *labe
   while (colind >= 0 && rowEnd > rowStart) {
     int c;
     c = *rowEnd--;
-    if ((c >= '0' && c <= '9') || c == '.') {
+    if ((c >= '0' && c <= '9') || c == '.' || c == ',') {
+      if (c == ',')
+        c = '.';
       numbuf[numpos--] = c;
     }
     else {
