@@ -32,7 +32,7 @@ static char *fixup(const char *inp)
   char *str = strdup(inp);
   if (strncmp(inp, "${prefix}", 9) == 0) {
     str = calloc(strlen(inp) + 100, 1);
-    sprintf(str, "%s%s", "/usr/local", inp + 9);
+    sprintf(str, "%s%s", "/usr", inp + 9);
   }
   return str;
 }
@@ -75,19 +75,19 @@ int main(int argc, char **argv)
         print_help_and_exit();
         break;
       case 's':
-        printf("%s -L%s/lib -lcomplearn\n", "-lz  -lcheck   -L/usr/lib -lgsl -lgslcblas -lm -L/usr/lib -lxml2 -Wl,--export-dynamic -lgobject-2.0 -lgmodule-2.0 -ldl -lglib-2.0   -lbz2", fixup("${prefix}"));
+        printf("%s -L%s/lib -lcomplearn\n", "-lz  -lcheck   -L/usr/lib -lgsl -lgslcblas -lm -lxml2 -Wl,--export-dynamic -lgobject-2.0 -lgmodule-2.0 -ldl -lglib-2.0   -lbz2", fixup("${prefix}"));
         break;
       case 'l':
         printf("-L%s/lib -lcomplearn\n", fixup("${prefix}"));
         break;
       case 'c':
-        printf("-I%s/include/complearn-1.0 %s\n", "/usr/local", "-DOPENMP_ENABLED=0");
+        printf("-I%s/include/complearn-1.0 %s\n", "/usr", "-DOPENMP_ENABLED=0");
         break;
       case 'e':
         printf("%s\n", fixup("${prefix}"));
         break;
       case 'p':
-        printf("%s\n", "/usr/local");
+        printf("%s\n", "/usr");
         break;
       case 'a':
         printf("1\n");
