@@ -296,11 +296,10 @@ void cmd_new_compressor(GString *inpkt, guint32 *curpos, GString *opkt)
 
 void *decode_pointer(GString *pkt, guint32 *cur_offset)
 {
-  guint32 u;
+  guint64 u = 0;
   void *ptr;
-  assert(sizeof(ptr) == 4);
   GString *str = decode_string(pkt, cur_offset);
-  sscanf(str->str, "%u", &u);
+  sscanf(str->str, "%lu", &u);
   ptr = (void *) u;
   g_string_free(str, TRUE);
   return ptr;
@@ -309,7 +308,8 @@ void *decode_pointer(GString *pkt, guint32 *cur_offset)
 void encode_pointer(GString *pkt, void *ptr)
 {
   char buf[128];
-  sprintf(buf, "%u", (guint32) ptr);
+  guint64 u = (guint64) ptr;
+  sprintf(buf, "%lu", u);
   encode_cstring(pkt, buf);
 }
 
@@ -340,7 +340,7 @@ void encode_string(GString *pkt, GString *enc)
 
 void encode_integer(GString *pkt, guint32 i)
 {
-  guint32 j = GUINT32_TO_LE(i);
+  guint32 j = GUINT32_TO_BE(i);
   g_string_append_len(pkt, (const gchar *) &j, 4);
 }
 
@@ -369,7 +369,7 @@ guint32 decode_integer(GString *pkt, guint32 *curpos)
 {
   guint32 result;
   g_assert((*curpos) + 3 < pkt->len);
-  result = GUINT32_FROM_LE(*(guint32 *)((gchar *)(pkt->str) + (*curpos)));
+  result = GUINT32_FROM_BE(*(guint32 *)((gchar *)(pkt->str) + (*curpos)));
   curpos[0] += 4;
   return result;
 }
@@ -410,7 +410,7 @@ GArray * decode_indexseq(GString *pkt, guint32 *curpos)
   GArray *res=g_array_new(FALSE,TRUE, sizeof(guint32));
   int len = decode_integer(pkt, curpos);
   int i;
-  fprintf(stderr, "Decoding integer array of size %d\n", len);
+//  fprintf(stderr, "Decoding integer array of size %d\n", len);
   for (i = 0; i < len; i += 1) {
     guint32 j = decode_integer(pkt, curpos);
     g_array_append_vals(res, &j, 1);
@@ -457,7 +457,7 @@ GString *decode_string(GString *pkt, guint32 *curpos)
 {
   guint32 len;
   g_assert((*curpos) + 3 < pkt->len);
-  len = GUINT32_FROM_LE(*(guint32 *)((gchar *)(pkt->str) + (*curpos)));
+  len = GUINT32_FROM_BE(*(guint32 *)((gchar *)(pkt->str) + (*curpos)));
   curpos[0] += 4;
   g_assert((*curpos) + len - 1 < pkt->len);
   GString *result = g_string_new_len(((gchar *)(pkt->str) + (*curpos)),len);
@@ -482,7 +482,7 @@ GString *unwrap_packet(GIOChannel *gi)
     fprintf(stderr, "Short packet error: %d/%d\n", actual, 4);
     exit(1);
   }
-  pkt_header = GUINT32_FROM_LE(pkt_header);
+  pkt_header = GUINT32_FROM_BE(pkt_header);
   g_assert(pkt_header >= 0 && pkt_header < 2000000000);
   if (pkt_header == 0)
     return g_string_new("");
@@ -505,7 +505,7 @@ GString *unwrap_packet(GIOChannel *gi)
 GString *wrap_packet(GString *inp)
 {
   guint32 pkt_header;
-  pkt_header = GUINT32_TO_LE(inp->len);
+  pkt_header = GUINT32_TO_BE(inp->len);
   GString *result = g_string_new_len((gchar *) &pkt_header, 4);
   g_string_append_len(result, (const gchar *) inp->str, inp->len);
   return result;
@@ -588,7 +588,7 @@ void cmd_cd_compression_matrix
 (GString *inpkt, guint32 *curpos, GString *opkt)
 {
   CompLearnCompressorDriver *res=decode_compressordriver(inpkt,curpos);
-  fprintf(stderr, "CCDres is %p\n", res);
+//  fprintf(stderr, "CCDres is %p\n", res);
   GArray *dim1, *dim2;
   dim1 = decode_indexseq(inpkt, curpos);
   dim2 = decode_indexseq(inpkt, curpos);
