@@ -27,7 +27,6 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 */
 #include <stdio.h>
-#include <signal.h>
 #include <string.h>
 #if OPENMP_ENABLED
 #include <omp.h>
@@ -235,23 +234,6 @@ char *complearn_make_temp_file_name(void)
   return result;
 }
 
-static GArray *toremove;
-
-void complearn_do_removals(void) {
-  int i;
-  if (toremove == NULL)
-    return;
-  for (i = 0; i < toremove->len; i += 1) {
-    char *t = g_array_index(toremove, char *, i);
-    complearn_remove_directory_recursively(t, 0);
-  }
-}
-
-static void complearn_controlchandler(int ignored) {
-  g_warning("Cleaning up...");
-  exit(1);
-}
-
 char *complearn_make_temp_dir_name(void)
 {
   int tid = 0;
@@ -260,11 +242,6 @@ char *complearn_make_temp_dir_name(void)
     tid = omp_get_thread_num();
 #endif
 
-  if (toremove == NULL) {
-    toremove = g_array_new(FALSE, TRUE, sizeof(gpointer));
-    g_atexit(complearn_do_removals);
-    signal(SIGINT, complearn_controlchandler);
-  }
   char *result = NULL, *tnam;
   int incr = 0;
   char pidbuf[64];
@@ -279,8 +256,6 @@ char *complearn_make_temp_dir_name(void)
       break;
     incr += 1;
   }
-  char *t = strdup(result);
-  g_array_append_val(toremove, t);
   return result;
 }
 
